==> org.eclipse.jdt.junit.runtime.source_3.4.1000.v20190510-0840.jar: org/eclipse/jdt/internal/junit/runner/JUnitMessages.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2008 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     David Saff (saff@mit.edu) - bug 102632: [JUnit] Support for JUnit 4.
 *******************************************************************************/
package org.eclipse.jdt.internal.junit.runner;

import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

public class JUnitMessages {

	private static final String BUNDLE_NAME= "org.eclipse.jdt.internal.junit.runner.JUnitMessages"; //$NON-NLS-1$

	private static final ResourceBundle RESOURCE_BUNDLE= ResourceBundle.getBundle(BUNDLE_NAME);

	private JUnitMessages() {
	}

	/**
	 * Gets a string from the resource bundle and formats it with the argument
	 *
	 * @param key the string used to get the bundle value, must not be null
	 * @param arg the single argument
	 * @return the formatted string
	 */
	public static String getFormattedString(String key, Object arg) {
		return MessageFormat.format(getString(key), new Object[] { arg });
	}

	/**
	 * Gets a string from the resource bundle and formats it with arguments
	 *
	 * @param key the string used to get the bundle value, must not be null
	 * @param args the arguments
	 * @return the formatted string
	 */
	public static String getFormattedString(String key, Object[] args) {
		return MessageFormat.format(getString(key), args);
	}

	public static String getString(String key) {
		try {
			return RESOURCE_BUNDLE.getString(key);
		} catch (MissingResourceException e) {
			return '!' + key + '!';
		}
	}
}

==> org.eclipse.jdt.junit.runtime.source_3.6.100.v20210708-1502.jar: org/eclipse/jdt/internal/junit/runner/JUnitMessages.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2008 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     David Saff (saff@mit.edu) - bug 102632: [JUnit] Support for JUnit 4.
 *******************************************************************************/
package org.eclipse.jdt.internal.junit.runner;

import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

public class JUnitMessages {

	private static final String BUNDLE_NAME= "org.eclipse.jdt.internal.junit.runner.JUnitMessages"; //$NON-NLS-1$

	private static final ResourceBundle RESOURCE_BUNDLE= ResourceBundle.getBundle(BUNDLE_NAME);

	private JUnitMessages() {
	}

	/**
	 * Gets a string from the resource bundle and formats it with the argument
	 *
	 * @param key the string used to get the bundle value, must not be null
	 * @param arg the single argument
	 * @return the formatted string
	 */
	public static String getFormattedString(String key, Object arg) {
		return MessageFormat.format(getString(key), arg);
	}

	/**
	 * Gets a string from the resource bundle and formats it with arguments
	 *
	 * @param key the string used to get the bundle value, must not be null
	 * @param args the arguments
	 * @return the formatted string
	 */
	public static String getFormattedString(String key, Object[] args) {
		return MessageFormat.format(getString(key), args);
	}

	public static String getString(String key) {
		try {
			return RESOURCE_BUNDLE.getString(key);
		} catch (MissingResourceException e) {
			return '!' + key + '!';
		}
	}
}
